@@ -7,7 +7,7 @@ use Path::Tiny qw( path );
 use Text::ParseWords qw( shellwords );
 
 # ABSTRACT: Legacy alien for libarchive
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
 
 
 sub new
@@ -18,14 +18,14 @@ sub new
 
 sub cflags
 {
-  wantarray   ## no critic (Freenode::Wantarray)
+  wantarray   ## no critic (Community::Wantarray)
     ? shellwords(Alien::Libarchive3->cflags)
     : Alien::Libarchive3->cflags;
 }
 
 sub libs
 {
-  wantarray   ## no critic (Freenode::Wantarray)
+  wantarray   ## no critic (Community::Wantarray)
     ? shellwords(Alien::Libarchive3->libs)
     : Alien::Libarchive3->libs;
 }
@@ -33,7 +33,7 @@ sub libs
 sub dlls
 {
   my @libs = Alien::Libarchive3->dynamic_libs;
-  wantarray ? @libs : $libs[0];   ## no critic (Freenode::Wantarray)
+  wantarray ? @libs : $libs[0];   ## no critic (Community::Wantarray)
 }
 
 sub version
@@ -94,7 +94,7 @@ Alien::Libarchive - Legacy alien for libarchive
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -117,7 +117,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
